Name: openssl
Version: 1.1.1g
Release: 1
License: OpenSSL
Summary: Open Source SSL/TLS toolkit
Url: https://www.openssl.org

BuildRequires: zlib-devel
BuildRequires: pase-build-tools

Source0: https://www.openssl.org/source/openssl-%{version}.tar.gz
Source1: openssl-1.1.1-ibmi.conf

Patch0: openssl-1.1.1-pase-support.patch
Patch1: openssl-1.1.1-no-test_shlibload.patch

%description
OpenSSL is an open source project that provides a robust, commercial-grade, and
full-featured toolkit for the Transport Layer Security (TLS) and Secure Sockets
Layer (SSL) protocols.

It also provides a general-purpose cryptography library.

%package -n libopenssl1_1
Summary: OpenSSL 1.1.x library

# TODO: This is a hack, but needed due to exports removed between RC9 and GA
# Previous OpenSSL 1.1 RCs exported various libc functions like memcpy, strcpy,
# etc somehow. For GA, this was cleaned up, but due to the linking order,
# NGINX and Node.js 10 link to the functions exported from libcrypto. This means
# that upon upgrading to libopenssl1_1 GA, it will break these packages unless
# they are upgraded. We can add new requires to those packages, but the only
# way to prevent the old packages from being installed with the new OpenSSL
# package is via these Conflicts tags. Remove when we're sufficiently sure
# that nobody is using the old packages anymore.
Conflicts: nodejs10 <= 10.11.0-0
Conflicts: nginx <= 1.15.2-1


%description -n libopenssl1_1
OpenSSL 1.1.x libraries

%package devel
Summary: OpenSSL development files
Requires: libopenssl1_1 = %{version}

%description devel
OpenSSL 1.1.x development files

%package engines
Summary: OpenSSL engines for cryptographic operations
Requires: libopenssl1_1 = %{version}

%description engines
Engines (plugins) for OpenSSL 1.1.x


%prep
%setup -q

%patch0 -p1
%patch1 -p1

cp %{SOURCE1} Configurations/50-ibmi.conf

%build

perl ./Configure \
%ifarch ppc64
  pase64-gcc \
%else
  pase-gcc \
%endif
  no-idea \
  no-mdc2 \
  no-rc5 \
  no-hw \
  no-egd \
  enable-tls1_3 \
  shared \
  threads \
  --prefix=%{_prefix} \
  --openssldir=%{_sysconfdir}/ssl \
  -Wl,-blibpath:%{_libdir}:/QOpenSys/usr/lib \
  -DOPENSSL_NO_SECURE_MEMORY \
  # end


make %_smp_mflags build_libs
svr4-shrlib libcrypto.so.1.1 libcrypto.so.1.1 %{_arch}

rm libssl.so.1.1
make %_smp_mflags build_libs
svr4-shrlib libssl.so.1.1 libssl.so.1.1 %{_arch}

%make_build


%check

make test


%install

%make_install

rm %{buildroot}/%{_libdir}/*.a

mkdir -p %{buildroot}/%{_datadir}/ssl
mv %{buildroot}%{_sysconfdir}/ssl/misc %{buildroot}/%{_datadir}/ssl

# shipped in ca-certificates now
rmdir %{buildroot}%{_sysconfdir}/ssl/certs

%files
%defattr(-, qsys, *none)

%{_bindir}/openssl
%{_bindir}/c_rehash

%{_datadir}/ssl
%{_mandir}/man1/*

%{_sysconfdir}/ssl

%files -n libopenssl1_1
%defattr(-, qsys, *none)

%{_libdir}/libcrypto.so.*
%{_libdir}/libssl.so.*

%files devel
%defattr(-, qsys, *none)

%{_libdir}/libcrypto.so
%{_libdir}/libssl.so

%{_libdir}/pkgconfig/*

%{_mandir}/man3/*
%{_mandir}/man5/*
%{_mandir}/man7/*

%{_docdir}/openssl

%{_includedir}/openssl

%files engines
%defattr(-, qsys, *none)

%{_libdir}/engines-1.1/*

%changelog
* Tue May 05 2020 Kevin Adler <kadler@us.ibm.com> - 1.1.1g
- Include patch level in version field

* Tue May 05 2020 Naveen Ram <naveen.ram@ibm.com> - 1.1.1g
- Upgrade to 1.1.1g
- Fixes CVE-2020-1967

* Tue Dec 10 2019 Kevin Adler <kadler@us.ibm.com> - 1.1.1
- Clean up descriptions

* Thu Dec 05 2019 Kevin Adler <kadler@us.ibm.com> - 1.1.1d
- Upgrade to 1.1.1d
- Fixes CVE-2019-1563
- Fixes CVE-2019-1549
- Fixes CVE-2019-1547
- Fixes CVE-2019-1543

* Fri Nov 08 2019 Mark Irish <mirish@ibm.com>
- Create 'engines' package for shipped engines

* Wed Oct 02 2019 Mark Irish <mirish@ibm.com> - 1.1.1
- Enabled ENGINE support

* Thu Mar 28 2019 Kevin Adler <kadler@us.ibm.com> - 1.1.1b
- Don't ship certs directory, moved to ca-certificates
- Update to 1.1.1b

* Tue Mar 26 2019 Kevin Adler <kadler@us.ibm.com> - 1.1.1
- ibm-build-tools -> pase-build-tools

* Wed Nov 14 2018 - Kevin Adler <kadler@us.ibm.com> - 1.1.1
- Update to OpenSSL 1.1.1 final release
- Add conflicts for packages built against older versions that used -bexpall
- Affected packages will also be rebuilt against this version

* Mon May 21 2018 - Kevin Adler <kadler@us.ibm.com>
- Upgrade to OpenSSL 1.1-pre6

* Tue Apr 10 2018 - Kevin Adler <kadler@us.ibm.com>
- Remove duplicate path in files section

* Mon Apr 09 2018 - Kevin Adler <kadler@us.ibm.com>
- Update OpenSSL 1.1.1 beta 2

* Mon Mar 12 2018 - Kevin Adler <kadler@us.ibm.com>
- Add unshipped doc files

* Sat Mar 03 2018 - Kevin Adler <kadler@us.ibm.com>
- Use svr4-shrlib from ibm-build-tools instead of private copy

* Mon Jan 22 2018 - Kevin Adler <kadler@us.ibm.com>
- Initial OpenSSL 1.1 support
